@@ -48,6 +48,9 @@ from .type_defs import (
     DescribeJobQueuesResponseTypeDef,
     DescribeJobsResponseTypeDef,
     DescribeSchedulingPoliciesResponseTypeDef,
+    EksConfigurationTypeDef,
+    EksPropertiesOverrideTypeDef,
+    EksPropertiesTypeDef,
     FairsharePolicyTypeDef,
     JobDependencyTypeDef,
     JobTimeoutTypeDef,
@@ -138,7 +141,8 @@ class BatchClient(BaseClient):
         unmanagedvCpus: int = ...,
         computeResources: ComputeResourceTypeDef = ...,
         serviceRole: str = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        eksConfiguration: EksConfigurationTypeDef = ...
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
         .
@@ -331,7 +335,8 @@ class BatchClient(BaseClient):
         propagateTags: bool = ...,
         timeout: JobTimeoutTypeDef = ...,
         tags: Mapping[str, str] = ...,
-        platformCapabilities: Sequence[PlatformCapabilityType] = ...
+        platformCapabilities: Sequence[PlatformCapabilityType] = ...,
+        eksProperties: EksPropertiesTypeDef = ...
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
         Registers an Batch job definition.
@@ -356,7 +361,8 @@ class BatchClient(BaseClient):
         retryStrategy: RetryStrategyTypeDef = ...,
         propagateTags: bool = ...,
         timeout: JobTimeoutTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        eksPropertiesOverride: EksPropertiesOverrideTypeDef = ...
     ) -> SubmitJobResponseTypeDef:
         """
         Submits an Batch job from a job definition.
